@@ -5,6 +5,8 @@ use base qw(App::gh::Command);
 use App::gh::Utils;
 
 
+# XXX: improve me
+
 =head1 NAME
 
 =head1 DESCRIPTION
@@ -15,16 +17,22 @@ Simply run git remote update --prune , git pull --all , then push back to writab
 
 sub run {
     my $self = shift;
-    my @lines = split /\n/,qx{ git remote -v | grep '(fetch)'};
+
+    unless ( -d ".git" ) {
+        die "Not a repository";
+    }
+
+
 
     _info "Running update --prune";
     qx{ git remote update --prune  };
 
+    my @lines = split /\n/,qx{ git remote -v | grep '(fetch)'};
     for my $line ( @lines ) {
         my ( $remote , $uri , $type ) = ($line =~ m{^(\w+)\s+(\S+)\s+\((\w+)\)} );
         # use Data::Dumper; warn Dumper( $remote , $uri , $type );
         _info "Updating from $remote ...";
-        qx{ git pull $remote };
+        qx{ git pull --rebase $remote };
 
         if( $uri =~ /^git\@github\.com/ ) {
             _info "Pushing changes to $remote : $uri";
